커피닉스, 시스템 엔지니어의 쉼터 커피향이 나는 *NIX
커피닉스
시스템/네트웍/보안을 다루는 곳
* HanIRC의 #coffeenix 방
[ 장비 및 회선 후원 ]
HOME > Unix/Linux 처음 시작하기 > OS 설치 도움말
검색 : 사이트 WHOIS 웹서버 종류


  RedHat Linux 설치 - KickStart 설치 작성일 : 2003/08/13 13:51
 
  • 글쓴이 : 문재식 ( http://redhat.okwecan.com/ )
  • 조회수 : 19372
          [ 이전화면 / 수정 ]   비밀번호 :     인쇄용 화면
     
    4. 레드햇 리눅스 KickStart 설치
    
    필자는 레드햇 리눅스를 5.0 시절부터 사용해 오면서 횟수를 알 수 없을 만큼 설치를 해 보았다. 하지만
    레드햇 리눅스의 설치에 관해 100% 이해를 하고 사용한 것은 아니었다. 설치를 하면서 방화벽의 개념도
    알 필요가 있고, RAID, LVM 의 이해도 필요하고, NIS, LDAP 등의 인증방법의 이해도 요구한다.
    
    결국 레드햇 리눅스의 설치에 관한 이해란 그리 쉬운 것 만큼은 아니라는 것이다. 가장 기본적인 설치
    방법만 이해하려하지 말고 레드햇이 지원해주는 다양한 설치를 시도해 본다면 더욱 많은 것을 얻을 수
    있을 것이다.
    
    Kickstart 설치는 여러분에게 레드햇 리눅스의 새로운 설치를 하도록 도와줄 것이다. Kickstart 는 우리
    에게 편리함을 주기 위해 개발되었다. 필자는 한 대의 머신에 설치한 레드햇과 동일하게 다른 머신에 설
    치하고자 하는데 사실 보통 귀찮은 것이 아니었다. 다른 건 몰라도 패키지를 사용자 정의로 해서 설치할
    경우 엄청나게 많은 시간과 노력이 필요했던 것이다. 하지만 이는 Kickstart 를 몰랐기 때문이었다.
    
    1) Kickstart 설치란 무엇인가?
    
    Kickstart 는 레드햇 리눅스의 설치를 자동화 시켜주는 것으로, 설치과정에서 필요로 하는 정보를 담은
    파일이 필요(ks.cfg)로 한다. Kickstart 설치는 하나의 서버 시스템에 담은 파일(ks.cfg)을 담아놓으면
    개별 컴퓨터에서 설치하는 동안 ks.cfg 파일을 읽어들여 설치를 자동화 하도록 한다.
    
    • 하나의 머신에서 레드햇 설치시 이전 설치와 똑같이 설치하고자 하는 경우
    • 네트워크에 있는 여러대의 머신을 모두 똑같이 설치하고자 하는 경우
    • 네트워크에 있는 여러대의 머신을 모두 다른 설정으로 자동 설치하고자 하는 경우
    2) Kickstart 설치 순서
    
    Kickstart 설치는 일반적인 설치와 마찬가지로 CD-ROM, hard drive, NFS, FTP or HTTP 등으로 설치할 수
    있다. Kickstart 설치는 어떤 순서로 하는지 알아 보도록 하자.
    
    1. Kickstart file (ks.cfg) 만들기
    2. Kickstart file 을 담은 부트디스크를 생성 또는 네트워크 설치 지원 환경 설정
    3. 레드햇 리눅스 설치 트리 생성
    4. Kickstart 설치 시작
    3) Kickstart file 만들기
    
    Kickstart 파일 만들기는 Kickstart 설치에서 가장 중요한 단계로 설치과정에서 필요로  하는 정보를 담
    고 있는 간단한 텍스트 파일이다. 이 파일을 처음부터 자기가 만들기는 어렵고 우리는 이미 만들어져 있
    는 파일을 수정하여 사용하도록 하자.
    
    레드햇 Documentation CD 가 있다면 RH-DOCS 디렉토리에 sample.ks 파일 복사하여 편집하고, 그렇지 않
    으면 Kickstart Configurator 를 사용하여 kickstart 파일을 생성한다.
    
    하지만 필자가 생각하기에 가장 좋은 방법은 레드햇 설치후 생성되는 샘플파일을 사용하는 것이다. 레드
    햇 리눅스 설치 프로그램은 설치과정에서 선택 또는 입력한 정보를 기반으로 kickstart 샘플 파일을 만
    들어 /root/anaconda-ks.cfg 파일에 저장한다. 여러분은 익숙한 편집기를 이용해 적당하게 편집하여 사
    용하면 된다.
    
    다음은 필자가 사용하는 kickstart file (ks.cfg) 의 일부이다. 패키지 설치부분을 제외하고는 설정파일
    의 내용을 그대로 옮겨 놓았다. 아래의 예제와 여러분의 anaconda-ks.cfg 파일을 비교해 가면서 여러분
    의 ks.cfg 파일을 생성해 보기 바란다.
    
    
    #######################################################
    # Kickstart file created by jaesik MUN, 2003.05.30
    #######################################################
    # Install Method - cdrom,harddrive,nfs,ftp,www
    install
    nfs --server=192.168.0.1 --dir=/home/nfs/RedHat/7.3

    # Sets the language to use during installation
    lang en_US

    # Sets the language(s) to install on the system
    # install english and korean, use english as the default language
    langsupport --default en_US.iso885915 en_US.iso885915 ko_KR.eucKR

    # Sets the keyboard and mouse type
    keyboard us
    mouse generic3ps/2 --device psaux

    # X is not configured on the installed system
    # If you want to configure X window system, use the xconfig option
    skipx

    # Configures network information for the system.
    # network --device eth0 --bootproto=static --ip=192.168.0.101 \
    # --netmask=255.255.255.0 --gateway=192.168.0.1 --nameserver=192.168.0.1

    # Use DHCP method
    network --device eth0 --bootproto=dhcp

    # Sets the system's root password, to be encrypted
    rootpw password

    # This option corresponds to the Firewall Configuration
    # firewall <securitylevel> [--trust=] <incoming> [--port]
    # firewall --medium --trust=eth1 --dhcp --port=imap:tcp,1234:udp
    firewall --disabled

    # Sets up the authentication options for the system.
    authconfig --enableshadow --enablemd5

    # Sets the system time zone
    timezone Asia/Seoul

    # Specifies how the boot loader should be installed and whether
    # the boot loader should be LILO or GRUB.
    bootloader

    # Removes partitions from the system, prior to creation of new
    # partitions. By default, no partitons are removed.
    clearpart --linux

    # Create a partition on the system
    part / --fstype ext3 --size=2048
    part swap --recommended
    part /home --fstype ext3 --size=1024 --grow
    part /usr/local --fstype ext3 --size=1024

    %packages
    @ Network Support
    @ Messaging and Web Tools
    @ NFS File Server
    @ Router / Firewall
    @ Network Managed Workstation
    @ Utilities
    @ Software Development
    lvm
    -micq
    -vim-enhanced

    %pre

    %post
    /sbin/chkconfig --level 345 apmd off
    /sbin/chkconfig --level 345 ipchains off
    /sbin/chkconfig --level 345 kudzu off
    kickstart file 은 Command 섹션, %packages 섹션, %pre 와 %post 섹션으로 구성되어 있으며 이들 순서
    는 절대로 바뀌어서는 안된다.
    
    • Command 섹션 : 여러 옵션으로 구성되며 필수옵션과 선택옵션으로 구분된다.
    • %packages 섹션 : 설치할 패키지를 선택하는 섹션이다. 패키지 그룹 또는 패키지를 입력한다.
    • %pre 와 %post 섹션 : 설치전 또는 설치후 수행해야할 명령을 입력하며 빈 공백으로 두어도 된다.
    Command 섹션에서 선택옵션은 생략이 가능하지만 필수옵션을 생략했을 경우 설치 프로그램은 해당 항목
    의 설치과정에서 설치 진행을 잠시 멈추고 사용자의 올바른 입력을 기다린다. 입력이 완료되면  설치를
    계속진행한다.
    
    4) Kickstart 옵션
    
    위의 예제에서 사용된 옵션을 중심으로 설명하겠다. 이 파일에서 사용된 옵션이 전부는 아니며 세부적인
    옵션은 Customization Guide 를 참고하기 바란다.
    
    설정파일의 내용을 이해하는게 어렵다면 GUI 환경의 [ Kickstart Configuration ] application 을 이용
    하여 kickstart file 을 생성할 수 있다.
    
    # Install Method - cdrom,harddrive,nfs,ftp,www
    install
    nfs --server=192.168.0.1 --dir=/home/nfs/RedHat/7.3
    install (선택)
    새로운 시스템을 설치하는 옵션이며, 기본모드이다. 설치를 위해서는 cdrom, harddrive, nfs 또는 url 중에서 하나를 설치 타입으로 지정해 주어야만 한다.
    여러분은 kickstart file 을 이용해 설치를 하기 전에 충분히 harddirve 또는 네트워크를 이용해 레드 햇을 설치할 줄 알아야 한다. 레드햇 설치에 관한 강좌를 참고 하기 바란다.
    cdrom
    시스템에 있는 CD-ROM 드라이브를 이용해 설치한다.

    harddrive
    vfat 또는 ext2 파일시스템을 갖는 로컬 드라이브로부터 설치한다. 레드햇 설치트리가 있는 파티션과 디렉토리를 옵션을 통해 알려주어야 한다.

    예 : harddrive --partition=hdb2 --dir=/tmp/install-tree

    nfs
    NFS 서버를 이용해 설치한다. NFS 서버의 위치와 설치트리가 있는 디렉토리를 설정한다. 다음 예제는 192.168.0.1 에 있는 NFS 서버의 /home/nfs/RedHat/7.3 디렉토리에 있는 레드햇 ISO 이미지를 이용해 설치하는 방법이다.

    예 : nfs --server=192.168.0.1 --dir=/home/nfs/RedHat/7.3

    url
    FTP 또는 HTTP 를 이용해 설치한다.
    # Sets the language to use during installation
    lang en_US

    # Sets the language(s) to install on the system
    # install english and korean, use english as the default language
    langsupport --default en_US.iso885915 ko_KR.eucKR
    lang (필수)
    설치하는 동안 사용할 언어를 설정한다. 영어는 en_US 이며, 한글은 ko_KR.eucKR 이다.

    예 : lang en_US
    langsupport (필수)
    설치후 사용할 언어를 선택하며, --default 옵션을 사용하여 1개 이상의 언어를 선택할 수 있다. 한국어를 설치하고자 한다면,

    예 : langsupport ko_KR.eucKR

    영어를 기본언어로 선택하고, 한국어를 추가선택한다면,

    langsupport --default en_US.iso885915 ko_KR.eucKR

    와 같이 설정한다.
    # Sets the keyboard and mouse type
    keyboard us
    mouse generic3ps/2 --device psaux
    keyboard (필수)
    키보드 타입을 설정한다. us 선택한다.
    mouse (필수)
    시스템에서 사용할 마우스 타입을 설정한다. 레드햇 버전과 사용자의 마우스 타입에 따라 모두 달라질 수 있는 설정이다. 여러분 시스템의 /root 디렉토리에 있는 anaconda-ks.cfg 파일의 설정을 참조하여 사용하도록 한다. 필자는 레드햇 7.3에서 3버튼의 ps/2 타입 마우스를 사용 설정을 하였다.

    예 : mouse generic3ps/2 --device psaux
    # X is not configured on the installed system
    # If you want to configure X window system, use the xconfig option
    skipx
    skipx (선택)
    시스템에 X 윈도우를 설치하지 않을 경우 선택하는 옵션으로, 설치과정에서 X 설정을 건너뛴다.
    xconfig (선택)
    X 윈도우를 설정하도록 한다. X 를 설치하고, 이 옵션을 생략하면 설치하는 동안에 사용자가 수동으로 X 를 설정하도록 한다. X 를 설치하지 않았다면 이 옵션을 사용해서는 안된다.

    --card=
    자신의 비디오 카드의 종류를 입력한다. 이 카드는 /usr/share/hwdata/Cards 의 목록에 포함되어 있어 야 한다. 이 값이 설정되지 않으면, 설치프로그램은 자동검색을 해서 찾을 것이다.

    --videoram=
    비디오카드가 사용하는 비디오램의 용량을 정의한다.

    --monitor=
    사용하는 모니터의 모델을 정의한다. 어떤 모니터 정보도 입력되지 않으면, 설치프로그램은 모델을 찾기 위해 자동검색을 실시한다. --hsync 또는 --vsync 값이 주어지면 이 옵션은 무시된다.

    --hsync=
    모니터의 수평주사율을 정의한다.

    --vsync=
    모니터의 수직주사율을 정의한다.

    --defaultdesktop=
    KDE 또는 GNOME 데스크탑 관련 패키지가 설치된다면, KDE 나 GNOME 둘중 하나를 기본 데스크탑으로 설정 한다.

    --startxonboot
    설치된 시스템에 그래픽 로그인을 사용하고자 하는 경우 설정한다.

    예 : xconfig --card "RIVA TNT2" --videoram 16384 --hsync 30-70 --vsync 50-150 \
    --resolution 1024x768 --depth 16 --startxonboot --defaultdesktop gnome
    (한줄로 작성한다.)
    # Configures network information for the system.
    # network --device eth0 --bootproto=static --ip=192.168.0.101 \
    # --netmask=255.255.255.0 --gateway=192.168.0.1 --nameserver=192.168.0.1

    # Use DHCP method
    network --device eth0 --bootproto=dhcp
    network (선택)
    NFS, FTP 또는 HTTP 등 네트워크를 이용한 kickstart 설치를 하는 경우 반드시 network 정보를 설정해 야 한다.

    --bootproto=
    아이피 번호를 받아오는 방식을 정의한다. DHCP 서버로부터 자동으로 할당받는다면 dhcp 또는 bootp 를 설정하고, 고정아이피를 사용한다면 static 를 설정하고 ip address, gateway, nameserver, netmask, hostname 등의 모든 네트워킹 정보를 kickstart file 에 주어져야 한다.

    DHCP 사용의 예 :
    network --device eth0 --bootproto=dhcp

    고정아이피 사용의 예 :
    network --device eth0 --bootproto=static --ip=192.168.0.101 \
    --netmask=255.255.255.0 --gateway=192.168.0.1 --nameserver=192.168.0.1

    주의할 점은 모든 네트워크 정보는 한 줄에 씌여져야 하며 위의 예제처럼 백슬래쉬(\) 사용한 랩 라인은 사용할 수 없다.

    --ip=
    아이피 번호를 설정한다.

    --gateway=
    기본 게이트웨이 주소를 설정한다.

    --nameserver=
    1차 네임서버 주소를 ip address 로 설정한다.

    --netmask=
    넷마스트를 설정한다.

    --hostname=
    설치된 시스템의 호스트네임을 설정한다.

    # Sets the system's root password, to be encrypted
    rootpw --iscrypted $1$5nUUszw9W3CTQcbMeXLrv.
    rootpw (필수)
    시스템에서 사용할 root 의 패스워드로 인자로 주어진 값을 암호화 하여 사용한다.

    예 : roowpw [--iscrypted] <password>

    --iscrypted
    이 옵션이 사용되면 패스워드 인자는 이미 암호화된 값으로 생각한다.
    # This option corresponds to the Firewall Configuration
    # firewall <securitylevel> [--trust=] <incoming> [--port]
    # firewall --medium --trust=eth1 --dhcp --port=imap:tcp,1234:udp
    firewall --disabled
    firewall (선택)
    firewall 옵션을 사용하기 위해서는 우선 레드햇 설치 가이드의 firewall 사용법에 관해 자세하게 숙지 하도록 하자. 이 강좌에서는 kickstart 에서의 사용방법만 설명한다.

    사용법 : firewall <securitylevel> [--trust=] <incoming> [--port]

    <securitylevel> : --high, --medium, --disabled

    예 : firewall --medium --ssh
    보안레벨을 medium 으로 설정하며 ssh 서비스는 허용한다.

    예 : firewall --medium --trust eth1
    보안레벨은 medium 이며 eth1 장치를 통해서 들어오는 모든 데이터는 허용한다.

    예 : firewall --disabled
    레드햇의 방화벽을 사용하지 않고 설치후 사용자 정의 방화벽을 설정을 허용한다.
    # Sets up the authentication options for the system.
    authconfig --enableshadow --enablemd5
    authconfig (필수)
    시스템의 인증방법에 관한 설정으로 기본적으로 암호화되며, shadow 시스템을 사용하지는 않는다.

    예 : authconfig --enablemd5 --enableshadow
    사용자의 암호를 md5 암호화 시키며, shadow 암호화 시스템을 사용하도록 한다.

    예 : authconfig --enablemd5 --enableshadow --enablenis --nisdomain=korea.com --nisserver=192.168.0.1
    NIS 서버로부터 인증을 거치기 위한 방법이다.

    --enablenis
    인증을 위해 NIS 서비스를 사용한다. 네트워크에서 사용할 NIS 도메인을 지정해 주어야 한다.

    --nisdomain
    NIS 서비스가 사용하는 NIS 도메인을 지정한다.

    --nisserver
    NIS 서버의 아이피 번호를 지정한다.
    # Sets the system time zone
    timezone Asia/Seoul
    timezone (필수)
    시스템에서 사용할 시간 영역을 설정한다.
    # Specifies how the boot loader should be installed and whether
    # the boot loader should be LILO or GRUB.
    bootloader
    bootloader (필수)
    GLUB 또는 LILO, 둘중 하나의 부트로더를 설치하도록 한다. GRUB 가 기본 부트로더이며, LILO 를 사용 하기 위해서는 --useLilo 옵션을 사용한다.

    --location=
    부트 레코드가 저장될 위치를 지정한다. mbr 이 기본값이며, partition 은 커널을 포함하는 파티션의 첫번째 섹터에 부트로더가 설치되며, none 은 부트로더를 설치하지 않는다.

    예 : bootloader --location=mbr
    기본 부트로더인 GRUB 를 mbr 영역에 설치한다.

    --password=
    GRUB 부트로더에 암호를 설정하여 GRUB 쉘에 접근하는 것을 제한할 수 있다. 이미 암호화된 암호를 가지고 있다면 --md5pass 옵션을 사용하도록 한다.
    예 : bootloader --location=mbr --password=password
    # Removes partitions from the system, prior to creation of new
    # partitions. By default, no partitons are removed.
    clearpart --linux

    # Create a partition on the system
    part / --fstype ext3 --size=2048
    part swap --recommended
    part /home --fstype ext3 --size=1024 --grow
    part /usr/local --fstype ext3 --size=1024
    clearpart (선택)
    파티션을 새롭게 만들기 전에 기존에 존재하던 파티션 테이블을 삭제한다. 기본값으로 어떤 파티션도 삭제되지 않는다.

    예 : clearpart --linux
    파티션 테이블에서 리눅스 파티션만 삭제한다.

    예 : clearpart -all
    시스템에 존재하는 모든 파티션을 삭제한다.
    part (필수)
    파티션을 생성하고 마운트 포인트를 지정한다. 존재하는 파티션이라면 --noformat 과 --onpart 옵션을 사용하지 않는다면 설치과정에서 모두 포맷될 것이다.

    예 : part / --fstype ext3 --size=2048
    2048MB 크기의 파티션을 생성한고, ext3 파일시스템으로 포맷한 후 / 로 마운트한다.

    예 : part /home --fstype ext3 --size=1024 --grow
    최소 1024MB, 여유공간이 남아있다면 최대크기로 파티션을 생성한 후 ext3로 포맷한고 /home 으로 마운트 한다.

    --grow
    여유공간 전체를 파티션의 영역으로 설정한다.

    --maxsize=
    파티션이 가질 수 있는 최대크기를 지정한다.

    --ondisk=
    디스크가 여려개 있을 경우 파티션을 생성할 디스크를 지정할 수 있다. 예를들어, --ondisk=hdb 는 두번째 하드디스크에 파티션을 생성한다.

    예 : part swap --recommended
    swap 파티션은 레드햇이 권장하는 크기로 설정한다. 레드햇은 메모리의 2배 크기를 swap 영역으로 권장한다.

    예 : part / --fstype ext3 --onpart hda1
    이미 존재하는 파티션 hda1 을 / 로 마운트 시키며, 파일시스템을 ext3로 포맷한다.

    예 : part /home --noformat --onpart hda2
    이미 존재하는 파티션 hda2 를 /home 으로 마운트 시키며, 포맷을 하지 않는다.
    5) Package Section
    
    %package 명령을 사용해 kickstart file 통해 설치할 패키지의 목록을 정의한다. 패키지는 그룹별 또는
    개별 패키지로 설정할 수 있으며, 레드햇 설치 CD-ROM 의 RedHat/base/comps.xml 에서 그룹의 목록을 
    볼 수 있다. 그룹이 선택되면 그룹에 포함되어 있는 기본 설치 패키지도 함께 설치가 된다.
    
    %packages
    @ Network Support
    @ Messaging and Web Tools
    @ NFS File Server
    @ Router / Firewall
    @ Network Managed Workstation
    @ Utilities
    @ Software Development
    lvm
    -micq
    -vim-enhanced
    %package
    위의 예제에서 보는 바와 같이 한줄에 하나의 그룹 또는 패키지를 나열하며, 그룹은 "@" 기호로 시작한다. lvm 과 같이 아무런 기호 없이 시작하는 것은 개별 패키지로 정의된 것이다. 그룹에 포함된 기본 패키지 를 설치하고 싶지 않다면 -micq 와 같이 "-" 기호를 패키지 앞에 붙여준다.

    --resolvedeps
    패키지 의존성문제를 자동으로 해결한다.

    --ignoredeps
    의존성 문제를 무시하며, 의존성에 관계없이 목록에 있는 패키지를 설치한다.
    6) Pre 섹션
    
    ks.cfg 파일을 읽어들인 후 곧바로 시스템에서 처리할 명령을 %pre 섹션에 추가할 수 있다. 네트워크에
    접근할 수 있지만 네임서비스가 설정되지 않았으므로 IP 번호를 사용한다.
    
    7) Post 섹션
    
    설치가 완료된 후 시스템에서 동작할 명령을 추가할 수 있다. 이 섹션은 %post 명령과 함께 시작하며, 
    설치후 설정변경, 원격 프로그램 설치 등을 할 수 있다.
    
    
    
    %post
    /sbin/chkconfig --level 345 apmd off
    /sbin/chkconfig --level 345 ipchains off
    /sbin/chkconfig --level 345 kudzu off
    8) 네트워크에서 Kickstart 파일 활용
    
    kickstart 파일을 부트 디스켓에 복사하여 활용하는 방법과 네트워크에서 활용하는 방법이 있는데, 우리
    는 여기에서 네트워크에 관한 방법만 이야기 하기로 한다.
    
    kickstart 을 이용한 네트워크 설치는 여러대의 컴퓨터를 빠르고 쉽게 설치할 수 있기 때문에 시스템 관
    리자들이 많이 사용하는 방법으로, 흔히 DHCP 서버와 NFS 서버를 활용한다.
    
    DHCP 서버는 클라이언트 시스템에 네트워킹 정보와 kickstart 파일의 위치 정보를 제공하며, NFS 서비스
    를 이용해 파일의 경로를 마운트하여 kickstart 파일을 이용할 수 있도록 한다.
    
    DHCP 서버와 NFS 서버를 구성하는 방법은 본 강좌의 밖이기 때문에 간단한 내용만  살펴보도록 하겠다.
    다음은 DHCP 설정파일의 예이다. DHCP 패키지가 설치되어 있는지 확인해 보고 없다면 설치를 먼저 한다.
    
    [/etc/dhcpd.conf]
    subnet 192.168.0.0 netmask 255.255.255.0 {
    # --- kickstart config
    filename "/home/nfs/Kickstart/ks.cfg";
    next-server 192.168.0.1;
    # --- default gateway
    option routers 192.168.0.1;
    option subnet-mask 255.255.255.0;
    option domain-name "korea.com";
    option domain-name-servers 192.168.0.1;

    option time-offset -18000; # Eastern Standard Time

    range 192.168.0.101 192.168.0.120;

    default-lease-time 21600;
    max-lease-time 43200;
    }
    dhcpd.conf 에서 next-server 는 NFS 서버의 아이피 번호이며, filename 은 kickstart 파일의 위치와 파
    일명이다. filename 의 값이 slash(/)로 끝나면 이를 디렉토리로 간주하고 NFS 서비스를 이용해 디렉토
    리를 마운트 한 후 kickstart 파일을 찾는다.
    
    위의 예제는 클라이언트에서 NFS 서버의 /home/nfs/Kickstart/ks.cfg 파일을 kickstart 파일로 읽어들이
    며, 만약 /home/nfs/Kickstart/ 만 입력되었다면 해당 디렉토리를 마운트 한후 <ip-addr>-kickstart 형
    식의 파일을 찾아 읽어들이게 된다.
    
    <ip-addr> 부분은 클라이언트 머신의 아이피번호를 뜻하므로, 192.168.0.101-kickstart 파일을 찾게된다.
    
    
    NFS 서비스는 nfs-utils 패키지가 설치되어 있어야 하며 portmap, nfs, nfslock 데몬이 동작하고 있어야
    한다. 확인후 /etc/exports 파일을 수정하도록 한다.
    
    [/etc/exports]
    /home/nfs     192.168.0.*(ro,all_squash,no_subtree_check)
    수정후 exportfs -ra 명령을 실행하여 설정 내용을 갱신하도록 한다.
    
    9) 레드햇 리눅스 설치트리 생성
    
    본 강좌에서는 NFS 를 이용한 네트워크 설치를 할 것이다. 따라서 서버의 /home/nfs/RedHat/7.3 디렉토
    리에 ISO 이미지를 복사해 두기 바란다. (install 명령 참조)
    
    10) Kickstart 설치 시작
    
    설치하고자 하는 머신에 RedHat CD-ROM 1번을 삽입하고 boot : 프롬프트가 뜨면 ks 를 입력후 엔터를 
    치면 kickstart 설치가 시작된다. 또는 네트워크 설치용 디스켓을 이용하여도 된다.
    
    ※ 참고문헌 : RedHat 8.0 Customization Guide
    
    
    
      커피닉스 카페 최근 글
    [06/16] [질문]SAN 스위치 브로드케이드 dcx8510-4 장비관련입니다.
    [04/22] Re: 영화속에 컴퓨터 이야기 ~스워드피쉬(2001)
    [10/20] Cross Compiler 깔
    [07/14] SSL АО
    [04/26] Re: 도스화면 원격조종 여부
    [04/25] 도스화면 원격조종 여부
    [10/30] Cshell에서 난수 설정
    [10/23] 공항철도주식회사 SE 구인 件
    [01/26] Re: wget으로 다른서버에있는 디렉토리를 가져오려고합니다.
    [01/25] wget으로 다른서버에있는 디렉토리를 가져오려고합니다.
    [01/11] 특정 안드로이드 WebView 버전에서 SSL 문제 (WebView 버그)
    [08/01] DNS forwarder (전달자) 서버를 통해서 쿼리하면 역방향을 받아오질 못합니다.
    [05/16] (주)후이즈 시스템엔지니어 (경력자) 모집
    [02/15] [AWS] Cloudfront edge 확인하기
    [01/20] Mobile Service/eCommerce 기업에서 Server / Java / PHP 개발자 구인
      New!   최근에 등록한 페이지
      KiCad EDA Suite project (Free/Libre/Open-Source EDA Suite) (CAD)
      오픈캐스케이드 캐드 (OpenCASCADE CAD)
      QCad for Windows --- GNU GPL (Free Software)
      The Hello World Collection
      IPMI를 활용한 리눅스 서버관리
      DNS 설정 검사
      nagiosgraph 설치 방법
      Slony-I 설치 방법 (postgresql replication tool)
      Qmail기반의 Anti spam 시스템 구축하기
      clusterssh

    [ 함께하는 사이트 ]




    운영진 : 좋은진호(truefeel), 야수(yasu), 범냉이, sCag
    2003년 8월 4일~